%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Project name: 
%
% Simulation of a column pulse tracer test
% launch file
%
% Code written by Dominique Claveau-Mallet
% Creation: 2019-04-03
% Updated: 2019-04-04
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% hydraulic properties (to be changed until proper calibration)
parm.D=5; %dispersivity (cm)
parm.ne=0.36; %effective porosity (-)
parm.Dn=5e-6; % exchange factor between effective and immobile porosity (s-1)
parm.factor=1; % correction factor between 0 and 1 to reduce the injected mass (in case the tail is not well reproduced)

%%% input parameters

% numerical
parm.database_path = 'C:\Program Files (x86)\USGS\Phreeqc Interactive 3.3.8-11728\database\phreeqc.dat';
parm.nbcell=10; % number of numerical cells

% slag properties
parm.slag.rho = 3.8;

% reactor geometry (1D column)
vol = 16*pi()*0.5^2; %empty bed volume (L)
mass = 24.239; %slag mass (kg)
parm.length=1.6; %length (m)
parm.radius=0.05; %radius (m)

% feeding
parm.duration=5; %duration (d)
Q=6.5; %influent flow rate (mL/min)
parm.mass=93; %injected tracer mass (ug)

%%% Calculated parameters

parm.n = (vol-(mass/parm.slag.rho))/vol; %total porosity (-)
HRTVtot =(vol-(mass/parm.slag.rho))/(60*0.001*Q); %total hydraulic retention time of voids (h)
parm.HRTVe=parm.ne*HRTVtot/parm.n; %effective hydraulic retention time of voids (h)

%%% Column tracer test

[output,F] = PHREEQCfct_tracer(parm);

plot(output(:,1),output(:,2),'-xk');
xlabel('Time (d)');
ylabel('Tracer (ug/L)');
